@@ -1,12 +1,9 @@
-package ifneeded Tcldot 2.38.0 "
+package ifneeded Tcldot 2.40.1 "
 	load [file join $dir libtcldot.so.0] Tcldot"
-package ifneeded Tclpathplan 2.38.0 "
+package ifneeded Tclpathplan 2.40.1 "
 	load [file join $dir libtclplan.so.0] Tclpathplan"
-package ifneeded Gdtclft 2.38.0 "
+package ifneeded Gdtclft 2.40.1 "
 	load [file join $dir libgdtclft.so.0] Gdtclft"
 package ifneeded gv 0 "
 	load [file join $dir libgv_tcl.so] gv"
-package ifneeded Tkspline 2.38.0 "
-	package require Tk 8.3
-	load [file join $dir libtkspline.so.0] Tkspline"
 # end
